@@ -166,11 +166,7 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
         setIconSize({22, 22});
 
     SettingsWidget::InitSettings();
-#if !defined Q_OS_ANDROID && !defined Q_OS_HAIKU
-    settings.init("MainWidget/WidgetsLocked", false);
-#else
     settings.init("MainWidget/WidgetsLocked", true);
-#endif
 
     QMPlay2GUI.menuBar = new MenuBar;
 
@@ -231,12 +227,13 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
             else if (QMPlay2Ext->canConvertAddress())
             {
                 tabifyDockWidget(playlistDock, dw);
+                dw->setVisible(true);
             }
             else
             {
                 tabifyDockWidget(videoDock, dw);
+                dw->setVisible(true);
             }
-            dw->setVisible(true);
         }
     }
 #else //On Android tabify docks (usually screen is too small)
@@ -290,6 +287,27 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
     volW = new VolWidget(settings.getInt("MaxVol"));
     mainTB->addWidget(volW);
 
+    if (auto menu = QMainWindow::createPopupMenu())
+    {
+        auto shortcuts = QMPlay2GUI.shortcutHandler;
+        for (QAction *act : menu->actions())
+        {
+            auto actParent = act->parent();
+            act->setAutoRepeat(false);
+            if (actParent == playlistDock)
+            {
+                shortcuts->appendAction(act, "KeyBindings/Widgets-playlistDock", "Shift+P");
+                addAction(act);
+            }
+            else if (actParent == infoDock)
+            {
+                shortcuts->appendAction(act, "KeyBindings/Widgets-infoDock", "Shift+I");
+                addAction(act);
+            }
+        }
+        menu->deleteLater();
+    }
+
     /**/
 
     Appearance::init();
@@ -476,7 +494,7 @@ MainWidget::MainWidget(QList<QPair<QString, QString>> &arguments)
                 double urlPos = 0.0;
                 if (settings.getBool("StoreUrlPos"))
                     urlPos = QMPlay2Core.getUrlPosSets().getDouble(url.toUtf8().toBase64(QByteArray::Base64UrlEncoding | QByteArray::OmitTrailingEquals));
-                if (urlPos <= 0.0 || abs(urlPos - pos) <= 0.75)
+                if (urlPos <= 0.0 || qAbs(urlPos - pos) <= 0.75)
                     seek(pos);
             }
         }
@@ -1107,14 +1125,12 @@ void MainWidget::toggleCompactView()
     {
         dockWidgetState = saveState();
 
-        hideAllExtensions();
+        hideDockWidgetsAndDisableFeatures();
 
 #if !defined Q_OS_MACOS && !defined Q_OS_ANDROID
         menuBar->hide();
 #endif
         mainTB->hide();
-        infoDock->hide();
-        playlistDock->hide();
         statusBar->hide();
         videoDock->show();
 
@@ -1132,6 +1148,8 @@ void MainWidget::toggleCompactView()
         restoreState(dockWidgetState);
         dockWidgetState.clear();
 
+        restoreDockWidgetFeatures();
+
 #if !defined Q_OS_MACOS && !defined Q_OS_ANDROID
         menuBar->setVisible(!hideMenuAct->isChecked());
 #endif
@@ -1199,21 +1217,7 @@ void MainWidget::toggleFullScreen()
         tb_movable = mainTB->isMovable();
         mainTB->setMovable(false);
 
-        infoDock->hide();
-        infoDock->setFeatures(DockWidget::NoDockWidgetFeatures);
-
-        playlistDock->hide();
-        playlistDock->setFeatures(DockWidget::NoDockWidgetFeatures);
-
-        addDockWidget(Qt::RightDockWidgetArea, videoDock);
-        for (QMPlay2Extensions *QMPlay2Ext : QMPlay2Extensions::QMPlay2ExtensionsList())
-            if (DockWidget *dw = QMPlay2Ext->getDockWidget())
-            {
-                if (dw->isVisible())
-                    visibleQMPlay2Extensions += QMPlay2Ext;
-                dw->hide();
-                dw->setFeatures(DockWidget::NoDockWidgetFeatures);
-            }
+        hideDockWidgetsAndDisableFeatures();
 
         videoDock->fullScreen(true);
         videoDock->show();
@@ -1282,11 +1286,7 @@ void MainWidget::toggleFullScreen()
         if (!visible) //jeżeli okno było wcześniej ukryte, to ma je znowu ukryć
             toggleVisibility();
 
-        infoDock->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
-        playlistDock->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
-        for (QMPlay2Extensions *QMPlay2Ext : QMPlay2Extensions::QMPlay2ExtensionsList())
-            if (QDockWidget *dw = QMPlay2Ext->getDockWidget())
-                dw->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
+        restoreDockWidgetFeatures();
 
 #if defined(Q_OS_ANDROID)
         menuBar->setVisible(true);
@@ -1302,8 +1302,6 @@ void MainWidget::toggleFullScreen()
 
         playlistDock->scrollToCurrectItem();
 
-        visibleQMPlay2Extensions.clear();
-
         QMPlay2GUI.screenSaver->unInhibit(1);
 
         setFocus();
@@ -1681,10 +1679,46 @@ QMenu *MainWidget::createPopupMenu()
         popupMenu->addAction(lockWidgetsAct);
     }
     for (QAction *act : popupMenu->actions())
-        act->setEnabled(isVisible() && !fullScreen && !isCompactView);
+    {
+        if (act->parentWidget() == mainTB)
+        {
+            act->setEnabled(isVisible() && !fullScreen && !isCompactView);
+            break;
+        }
+    }
     return popupMenu;
 }
 
+void MainWidget::hideDockWidgetsAndDisableFeatures()
+{
+    infoDock->hide();
+    infoDock->setFeatures(DockWidget::NoDockWidgetFeatures);
+
+    playlistDock->hide();
+    playlistDock->setFeatures(DockWidget::NoDockWidgetFeatures);
+
+    addDockWidget(Qt::RightDockWidgetArea, videoDock);
+    for (QMPlay2Extensions *QMPlay2Ext : QMPlay2Extensions::QMPlay2ExtensionsList())
+    {
+        if (DockWidget *dw = QMPlay2Ext->getDockWidget())
+        {
+            if (dw->isVisible())
+                visibleQMPlay2Extensions += QMPlay2Ext;
+            dw->hide();
+            dw->setFeatures(DockWidget::NoDockWidgetFeatures);
+        }
+    }
+}
+void MainWidget::restoreDockWidgetFeatures()
+{
+    infoDock->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
+    playlistDock->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
+    for (QMPlay2Extensions *QMPlay2Ext : QMPlay2Extensions::QMPlay2ExtensionsList())
+        if (QDockWidget *dw = QMPlay2Ext->getDockWidget())
+            dw->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable);
+    visibleQMPlay2Extensions.clear();
+}
+
 void MainWidget::showToolBar(bool showTB)
 {
     if (showTB && (!mainTB->isVisible() || !statusBar->isVisible()))
