@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2024  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -174,6 +174,13 @@ void PlaylistDock::scrollToCurrectItem()
     list->scrollToItem(list->currentItem());
 }
 
+void PlaylistDock::showEvent(QShowEvent *e)
+{
+    DockWidget::showEvent(e);
+    if (qobject_cast<QAction *>(sender()))
+        raise();
+}
+
 void PlaylistDock::expandTree(QTreeWidgetItem *i)
 {
     while (i)
