@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2024  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -19,15 +19,16 @@
 #pragma once
 
 #define DecoderName "FFmpeg Decoder"
+#define DecoderVkVideoName "FFmpeg Vulkan Decoder"
 #define DecoderVAAPIName "FFmpeg VA-API Decoder"
 #define DecoderVDPAUName "FFmpeg VDPAU Decoder"
-#define DecoderVDPAU_NWName DecoderVDPAUName " (no output)"
 #define DecoderDXVA2Name "FFmpeg DXVA2 Decoder"
 #define DecoderD3D11VAName "FFmpeg D3D11VA Decoder"
 #define DecoderVTBName "FFmpeg VideoToolbox Decoder"
 #define DemuxerName "FFmpeg"
 #define VAAPIWriterName "VA-API"
 #define VDPAUWriterName "VDPAU"
+#define VkVideoWriterName "VkVideo"
 #define FFReaderName "FFmpeg Reader"
 
 #ifdef FIND_HWACCEL_DRIVERS_PATH
