@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2024  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -34,8 +34,7 @@ extern "C"
 FFDec::FFDec() :
     codec_ctx(nullptr),
     packet(nullptr),
-    frame(nullptr),
-    codecIsOpen(false)
+    frame(nullptr)
 {}
 FFDec::~FFDec()
 {
@@ -57,12 +56,7 @@ void FFDec::destroyDecoder()
     clearFrames();
     av_frame_free(&frame);
     av_packet_free(&packet);
-    if (codecIsOpen)
-    {
-        avcodec_close(codec_ctx);
-        codecIsOpen = false;
-    }
-    av_freep(&codec_ctx);
+    avcodec_free_context(&codec_ctx);
 }
 
 void FFDec::clearFrames()
@@ -79,6 +73,8 @@ AVCodec *FFDec::init(StreamInfo &streamInfo)
     if (codec)
     {
         codec_ctx = avcodec_alloc_context3(codec);
+        if (!codec_ctx)
+            return nullptr;
         avcodec_parameters_to_context(codec_ctx, streamInfo.params);
 //        codec_ctx->debug_mv = FF_DEBUG_VIS_MV_P_FOR | FF_DEBUG_VIS_MV_B_FOR | FF_DEBUG_VIS_MV_B_BACK;
     }
@@ -103,7 +99,7 @@ bool FFDec::openCodec(AVCodec *codec)
         default:
             break;
     }
-    return (codecIsOpen = true);
+    return true;
 }
 
 void FFDec::decodeFirstStep(const Packet &encodedPacket, bool flush)
@@ -128,6 +124,10 @@ int FFDec::decodeStep(bool &frameFinished)
         bytesConsumed = packet->size;
         sendOk = true;
     }
+    else if (sendErr == AVERROR_EXTERNAL)
+    {
+        m_libError = true;
+    }
 
     for (;;)
     {
