@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2024  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -34,6 +34,9 @@
 #include <QPainter>
 #include <QLibrary>
 #include <QWidget>
+#ifdef Q_OS_WIN
+#   include <QOperatingSystemVersion>
+#endif
 
 /* OpenGL|ES 2.0 doesn't have those definitions */
 #ifndef GL_MAP_WRITE_BIT
@@ -186,7 +189,7 @@ void OpenGLCommon::initialize(const std::shared_ptr<OpenGLHWInterop> &hwInterop)
 #ifdef Q_OS_WIN
 void OpenGLCommon::setWindowsBypassCompositor(bool bypassCompositor)
 {
-    if (!bypassCompositor && QSysInfo::windowsVersion() <= QSysInfo::WV_6_1) // Windows 7 and Vista can disable DWM composition, so check it
+    if (!bypassCompositor && QOperatingSystemVersion::current() <= QOperatingSystemVersion::Windows7) // Windows 7 and Vista can disable DWM composition, so check it
     {
         using DwmIsCompositionEnabledProc = HRESULT (WINAPI *)(BOOL *pfEnabled);
         if (auto DwmIsCompositionEnabled = (DwmIsCompositionEnabledProc)GetProcAddress(GetModuleHandleA("dwmapi.dll"), "DwmIsCompositionEnabled"))
@@ -241,7 +244,7 @@ void OpenGLCommon::initializeGL()
 {
     initializeOpenGLFunctions();
 
-#if !defined(QT_OPENGL_ES_2)
+#if !defined(QT_OPENGL_ES_2) && !defined(QT_FEATURE_opengles2)
     if (hasPbo && !m_glInstance->hasMapBufferRange)
     {
         Q_ASSERT(m_glInstance->hasMapBuffer);
@@ -465,7 +468,7 @@ void OpenGLCommon::paintGL()
                     quint8 *dst = nullptr;
                     if (m_glInstance->hasMapBufferRange)
                         dst = (quint8 *)glMapBufferRange(GL_PIXEL_UNPACK_BUFFER, 0, w * h * bytesMultiplier, GL_MAP_WRITE_BIT | GL_MAP_INVALIDATE_BUFFER_BIT);
-#if !defined(QT_OPENGL_ES_2)
+#if !defined(QT_OPENGL_ES_2) && !defined(QT_FEATURE_opengles2)
                     else
                         dst = (quint8 *)m_gl15.glMapBuffer(GL_PIXEL_UNPACK_BUFFER, GL_WRITE_ONLY);
 #endif
@@ -634,7 +637,7 @@ void OpenGLCommon::paintGL()
                 quint8 *dst = nullptr;
                 if (m_glInstance->hasMapBufferRange)
                     dst = (quint8 *)glMapBufferRange(GL_PIXEL_UNPACK_BUFFER, 0, dataSize, GL_MAP_WRITE_BIT | GL_MAP_INVALIDATE_BUFFER_BIT);
-#if !defined(QT_OPENGL_ES_2)
+#if !defined(QT_OPENGL_ES_2) && !defined(QT_FEATURE_opengles2)
                 else
                     dst = (quint8 *)m_gl15.glMapBuffer(GL_PIXEL_UNPACK_BUFFER, GL_WRITE_ONLY);
 #endif
